export declare class Value {
    /**
     * new Value によって作られた値の配列
     * @private
     */
    static _values: {
        [key: string]: any;
    }[];
    /**
     * 有効期限を管理するオブジェクト
     * @private
     */
    static _expires: {
        [key: string]: number | null;
    }[];
    /**
     * storage 指定によって指定された storage の配列
     * @private
     */
    static _storages: Storage[];
    /**
     * 全ての Value インスタンスを storage に保存
     */
    static flush(): void;
    /**
     * 全ての Value インスタンスを初期化
     */
    static clear(): void;
    /**
     * storage に保存されている期限切れデータを全て削除します。
     * どんな storage が使われているかは１つでもインスタンス化されてないとわからないので、
     * gc する storage は Value._storages にあるものだけを対象にします。
     */
    static gc(): void;
    /**
     * 有効期限用のキーを生成
     * @private
     */
    static _expiresKeyGen(key: string): string;
    /**
     * localStorage が利用可能かどうか
     * @private
     */
    static _isLocalStorageAvailable(): boolean;
    /**
     * namespace 指定をした Value を返す
     */
    static namespace(name: string): (key: string, opt?: Option) => Value;
    private storage;
    private defaults;
    private expires;
    private debouncedFlush;
    private namespace;
    private key;
    private storageId;
    constructor(key: string, opt?: Option);
    /**
     * Value インスタンスの内容を storage に保存
     */
    flush(): void;
    /**
     * Value インスタンスの内容を初期化
     * storage の内容も削除
     */
    clear(): void;
    get useDefault(): boolean;
    get value(): any;
    set value(value: any);
    /**
     * 有効期限が切れているかどうか
     */
    get isExpired(): boolean;
}
export declare type Option = {
    storage?: Storage;
    default?: any;
    expires?: number;
    debounceTime?: number;
    namespace?: string;
};
export default Value;
